unit klibc;

{$mode objfpc}

interface

uses
  Classes, SysUtils;
const
  clib='c';

type
  TFileDescriptor = type Integer;
  TSocket = TFileDescriptor;
  in_addr_t = UInt32;
  socklen_t = Cardinal;
  THostEnt = packed record
    h_name: PChar;                  { Official name of host.  }
    h_aliases: PPChar;              { Alias list.  }
    h_addrtype: Integer;            { Host address type.  }
    h_length: socklen_t;            { Length of address.  }
    case Byte of
      0: (h_addr_list: PPChar);     { List of addresses from name server.  }
      1: (h_addr: PPChar);          { Address, for backward compatibility.  }
  end;
  PHostEnt = ^THostEnt;

  Tservent = packed record
    s_name: PChar;
    s_aliases: PPChar;
    s_port: Integer;
    s_proto: PChar;
  end;
  PServent = ^Tservent;

  Tprotoent = packed record
    p_name: PChar;
    p_aliases: ^PChar;
    p_proto: WORD; //u_short;
  end;
  PProtoent = ^TProtoent;
  size_t = LongWord;

  SunB = {packed} record
    s_b1, s_b2, s_b3, s_b4: char;
  end;

  SunW = {packed} record
    s_w1, s_w2: Word;
  end;

  in_addr = packed record
    case Integer of
      0: (S_un_b: SunB);
      1: (S_un_w: SunW);
      2: (S_addr: LongWord);
  end;
  Pin_addr = ^in_addr;

function fpinet_addr(cp: PChar): in_addr_t;
function fpinet_ntoa(__in: in_addr): PChar;
function fpgethostbyaddr(addr: Pointer;  len: socklen_t; __type: Integer): PHostEnt;
function fpgethostbyname(name: PChar): PHostEnt;
function fpgetservbyname(name: PChar; proto: PChar): PServEnt;
function fpgetprotobyname(name: PChar): PProtoEnt;
function fpgetdomainname(Name: PChar; Len: size_t): Integer;
function fpgethostname(Name: PChar; Len: socklen_t): Integer;
function fpshutdown(fd: TSocket; how: Integer): Integer;

{Libc functions}
{in_addr_t inet_addr(const char *cp);}
function inet_addr (cp: Pchar):in_addr_t;cdecl;external clib name 'inet_addr';
{int inet_aton(const char *cp, struct in_addr *inp);}
function inet_aton (cp: Pchar; inp: Pin_addr): Integer;
         cdecl;external clib name 'inet_aton';
{char *inet_ntoa(struct in_addr in);}
function inet_ntoa(__in: in_addr): PChar;cdecl;external clib name 'inet_ntoa';
{struct hostent *gethostbyaddr(const void *addr,socklen_t len, int type);}
function gethostbyaddr(addr: Pointer; len: socklen_t; __type: Integer): PHostEnt;
         cdecl;external clib name 'gethostbyaddr';
{struct hostent *gethostbyname(const char *name);}
function gethostbyname(name: PChar): PHostEnt;cdecl;external clib name 'gethostbyname';
{struct servent *getservbyname(const char *name, const char *proto);}
function getservbyname(name: PChar; proto: PChar): PServEnt;
         cdecl;external clib name 'getservbyname';
{struct protoent *getprotobyname(const char *name);}
function getprotobyname(name: PChar): PProtoEnt;cdecl;external clib name 'getprotobyname';
{int getdomainname(char *name, size_t len);}
function getdomainname(Name: PChar; Len: size_t): Integer;
         cdecl;external clib name 'getdomainname';
{int gethostname(char *name, size_t len);}
function gethostname(Name: PChar; Len: socklen_t): Integer;
         cdecl;external clib name 'gethostname';
{int shutdown(int sockfd, int how);}
function shutdown(fd: TSocket; how: Integer): Integer;
         cdecl;external clib name 'shutdown';
{}

implementation

function fpinet_addr(cp: PChar): in_addr_t;
begin
  Result := inet_addr(cp);
end;

function fpinet_ntoa(__in: in_addr): PChar;
begin
  Result := inet_ntoa(__in);
end;

function fpgethostbyaddr(addr: Pointer; len: socklen_t; __type: Integer
  ): PHostEnt;
begin
  Result := gethostbyaddr(addr,len,__type);
end;

function fpgethostbyname(name: PChar): PHostEnt;
begin
  Result := gethostbyname(name);
end;

function fpgetservbyname(name: PChar; proto: PChar): PServEnt;
begin
  Result := getservbyname(name,proto);
end;

function fpgetprotobyname(name: PChar): PProtoEnt;
begin
  Result := getprotobyname(name);
end;

function fpgetdomainname(Name: PChar; Len: size_t): Integer;
begin
  Result := getdomainname(Name,Len);
end;

function fpgethostname(Name: PChar; Len: socklen_t): Integer;
begin
  Result := gethostname(Name,Len);
end;

function fpshutdown(fd: TSocket; how: Integer): Integer;
begin
  Result := shutdown(fd,how);
end;

end.

